@@ -1,8 +1,7 @@
-from .ip2 import get_client_ip
-
+from .ip import get_client_ip  # noqa
 
 default_app_config = 'ipware.apps.IPwareConfig'
 
 __author__ = 'Val Neekman @ Neekware Inc. [@vneekman]'
 __description__ = "A Django application to retrieve user's IP address"
-__version__ = '2.1.0'
+__version__ = '3.0.0'
